Utils — Kivy v1.0.1-dev documentation

# Utils

`kivy.utils.` `intersection`(set1, set2)

  Return intersection between 2 list

`kivy.utils.` `difference`(set1, set2)

  Return difference between 2 list

`kivy.utils.` `curry`(fn, *cargs, **ckwargs)

  Change the function signature to pass new variable.

`kivy.utils.` `strtotuple`(s)

  Convert a tuple string into tuple, with some security check. Designed to be used with eval() function

      a = (12, 54, 68)
      b = str(a)         # return '(12, 54, 68)'
      c = strtotuple(b)  # return (12, 54, 68)

`kivy.utils.` `get_color_from_hex`(s)

  Transform from hex string color to kivy color

`kivy.utils.` `get_random_color`(alpha=1.0)

  Returns a random color (4 tuple)

  Parameters : | alpha : float, default to 1.0 if alpha == ‘random’ a random alpha value is generated

`kivy.utils.` `is_color_transparent`(c)

  Return true if alpha channel is 0

`kivy.utils.` `boundary`(value, minvalue, maxvalue)

  Limit a value between a minvalue and maxvalue

`kivy.utils.` `deprecated`(func)

  This is a decorator which can be used to mark functions as deprecated. It will result in a warning being emitted the first time the function is used.

class `kivy.utils.` `SafeList`

  Bases: `list`

  List with clear() method

  Warning

  Usage of iterate() function will decrease your performance.

`kivy.utils.` `interpolate`(value_from, value_to, step=10)

  Interpolate a value to another. Can be useful to smooth some transition. For example

      # instead of setting directly
      self.pos = pos

      # use interpolate, and you'll have a nice transition
      self.pos = interpolate(self.pos, new_pos)

  Warning

  This interpolation work only on list/tuple/double with the same dimension. No test are done if the dimension is not the same.